//Code taken from 
//https://extensions.gnome.org/extension/368/taskbar-with-desktop-button-to-minimizeunminimize-/ 
//by Xes http://svn.xesnet.fr/gnomeextensions

const Gtk = imports.gi.Gtk;
const Lang = imports.lang;

const Extension = imports.misc.extensionUtils.getCurrentExtension();
const Lib = Extension.imports.lib;

const schema = "org.gnome.shell.extensions.TaskBar";

function init()
{

}

function buildPrefsWidget()
{
    let prefs = new Prefs(schema);

    return prefs.buildPrefsWidget();
}

function Prefs(schema)
{
    this.init(schema);
}

Prefs.prototype =
{
    settings: null,

    init: function(schema)
    {
	let settings = new Lib.Settings(schema);
	
	this.settings = settings.getSettings();
    },

    changeRemoveDefaultApplicationMenu: function(object, pspec)
    {
	this.settings.set_boolean("remove-default-application-menu", object.active);
    },
    
    changeDisplayDesktopButton: function(object, pspec)
    {
	this.settings.set_boolean("display-desktop-button", object.active);
    },

    changeCloseButton: function(object, pspec)
    {
	this.settings.set_boolean("close-button", object.active);
    },

    changeIconSize: function(object, valueIconSize)
    {
	this.settings.set_int("icon-size", valueIconSize.get_value());
    },
    
    changePanelPosition: function(object, _valuePanelPosition)
    {
	this.settings.set_int("panel-position", this._valuePanelPosition.get_value());
    },

    changeDisplayPreview: function(object, pspec)
    {
	this.settings.set_boolean("display-preview", object.active);
    },

    changePreviewSize: function(object, valuePreviewSize)
    {
	this.settings.set_int("preview-size", valuePreviewSize.get_value());
    },

    changePreviewDelay: function(object, valuePreviewDelay)
    {
	this.settings.set_int("preview-delay", valuePreviewDelay.get_value());
    },

    buildPrefsWidget: function()
    {
	let frame = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL, border_width: 10});

	let label = new Gtk.Label({ label: "<b>Global</b>", use_markup: true, xalign: 0});
	let vbox = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL, margin_left: 20});



	let hboxRemoveDefaultApplicationMenu = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL});
	let labelRemoveDefaultApplicationMenu = new Gtk.Label({label: "Remove Default Application Menu", xalign: 0});
	let valueRemoveDefaultApplicationMenu = new Gtk.Switch({active: this.settings.get_boolean("remove-default-application-menu")});
	valueRemoveDefaultApplicationMenu.connect('notify::active', Lang.bind(this, this.changeRemoveDefaultApplicationMenu));

	hboxRemoveDefaultApplicationMenu.pack_start(labelRemoveDefaultApplicationMenu, true, true, 0);
	hboxRemoveDefaultApplicationMenu.add(valueRemoveDefaultApplicationMenu);
	vbox.add(hboxRemoveDefaultApplicationMenu);


	let hboxDisplayDesktopButton = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL});
	let labelDisplayDesktopButton = new Gtk.Label({label: "Display Desktop Button", xalign: 0});
	let valueDisplayDesktopButton = new Gtk.Switch({active: this.settings.get_boolean("display-desktop-button")});
	valueDisplayDesktopButton.connect('notify::active', Lang.bind(this, this.changeDisplayDesktopButton));

	hboxDisplayDesktopButton.pack_start(labelDisplayDesktopButton, true, true, 0);
	hboxDisplayDesktopButton.add(valueDisplayDesktopButton);
	vbox.add(hboxDisplayDesktopButton);



	let hboxCloseButton = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL});
	let labelCloseButton = new Gtk.Label({label: "Middle Click Close task", xalign: 0});
	let valueCloseButton = new Gtk.Switch({active: this.settings.get_boolean("close-button")});
	valueCloseButton.connect('notify::active', Lang.bind(this, this.changeCloseButton));

	hboxCloseButton.pack_start(labelCloseButton, true, true, 0);
	hboxCloseButton.add(valueCloseButton);
	vbox.add(hboxCloseButton);



	let hboxIconSize = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL});
	let labelIconSize = new Gtk.Label({label: "Icon Size ", xalign: 0});
	let valueIconSize = new Gtk.Adjustment({lower: 1, upper: 96, step_increment: 1});
	let value2IconSize = new Gtk.SpinButton({adjustment: valueIconSize, snap_to_ticks: true});
	value2IconSize.set_value(this.settings.get_int("icon-size"));
	value2IconSize.connect("value-changed", Lang.bind(this, this.changeIconSize, valueIconSize));

	hboxIconSize.pack_start(labelIconSize, true, true, 0);
	hboxIconSize.add(value2IconSize);
	vbox.add(hboxIconSize);



	let hboxPanelPosition = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL});
	let labelPanelPosition = new Gtk.Label({label: "Panel Position", xalign: 0});
	let valuePanelPosition = new Gtk.Scale.new_with_range(Gtk.Orientation.HORIZONTAL, 1, 9, 1);
	valuePanelPosition.set_value(this.settings.get_int("panel-position"));
    valuePanelPosition.set_digits(0);
    valuePanelPosition.set_hexpand(true);
	valuePanelPosition.connect('value-changed', Lang.bind(this, this.changePanelPosition));
	this._valuePanelPosition = valuePanelPosition;	

	hboxPanelPosition.pack_start(labelPanelPosition, true, true, 0);
	hboxPanelPosition.add(valuePanelPosition);
	vbox.add(hboxPanelPosition);
	


	frame.add(label);
	frame.add(vbox);

	label = new Gtk.Label({ label: "\n<b>Preview</b>", use_markup: true, xalign: 0 });
	vbox = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL, margin_left: 20 });



	let hboxDisplayPreview = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL});
	let labelDisplayPreview = new Gtk.Label({label: "Display Preview", xalign: 0});
	let valueDisplayPreview = new Gtk.Switch({active: this.settings.get_boolean("display-preview")});
	valueDisplayPreview.connect('notify::active', Lang.bind(this, this.changeDisplayPreview));

	hboxDisplayPreview.pack_start(labelDisplayPreview, true, true, 0);
	hboxDisplayPreview.add(valueDisplayPreview);
	vbox.add(hboxDisplayPreview);



	let hboxPreviewSize = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL});
	let labelPreviewSize = new Gtk.Label({label: "Preview size ", xalign: 0});
	let valuePreviewSize = new Gtk.Adjustment({lower: 100, upper: 1000, step_increment: 50});
	let value2PreviewSize = new Gtk.SpinButton({adjustment: valuePreviewSize, snap_to_ticks: true});
	value2PreviewSize.set_value(this.settings.get_int("preview-size"));
	value2PreviewSize.connect("value-changed", Lang.bind(this, this.changePreviewSize, valuePreviewSize));

	hboxPreviewSize.pack_start(labelPreviewSize, true, true, 0);
	hboxPreviewSize.add(value2PreviewSize);

	vbox.add(hboxPreviewSize);



	let hboxPreviewDelay = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL});
	let labelPreviewDelay = new Gtk.Label({label: "Delay before Preview (milliseconds)", xalign: 0});
	let valuePreviewDelay = new Gtk.Adjustment({lower: 0, upper: 3000, step_increment: 250});
	let value2PreviewDelay = new Gtk.SpinButton({adjustment: valuePreviewDelay, snap_to_ticks: true});
	value2PreviewDelay.set_value(this.settings.get_int("preview-delay"));
	value2PreviewDelay.connect("value-changed", Lang.bind(this, this.changePreviewDelay, valuePreviewDelay));

	hboxPreviewDelay.pack_start(labelPreviewDelay, true, true, 0);
	hboxPreviewDelay.add(value2PreviewDelay);

	vbox.add(hboxPreviewDelay);



	frame.add(label);
	frame.add(vbox);
	frame.show_all();
	
	return frame;
    }
}
